# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12gcp/gcp_data.proto\x12\x14oak9.tython.gcp.data\x1a\x13shared/shared.proto\"\xe1\x01\n\x1f\x44\x61taCatalogEntryXGcsFilesetSpec\x12\x15\n\rfile_patterns\x18\x01 \x03(\t\x12l\n\x15sample_gcs_file_specs\x18\x02 \x03(\x0b\x32M.oak9.tython.gcp.data.DataCatalogEntryXGcsFilesetSpec.SampleGcsFileSpecsEntry\x1a\x39\n\x17SampleGcsFileSpecsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"K\n\x19\x44\x61taCatalogEntryXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x98\x06\n\x10\x44\x61taCatalogEntry\x12g\n\x1a\x62igquery_date_sharded_spec\x18\x01 \x03(\x0b\x32\x43.oak9.tython.gcp.data.DataCatalogEntry.BigqueryDateShardedSpecEntry\x12Z\n\x13\x62igquery_table_spec\x18\x02 \x03(\x0b\x32=.oak9.tython.gcp.data.DataCatalogEntry.BigqueryTableSpecEntry\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\x13\n\x0b\x65ntry_group\x18\x05 \x01(\t\x12\x10\n\x08\x65ntry_id\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\x19\n\x11integrated_system\x18\x08 \x01(\t\x12\x17\n\x0flinked_resource\x18\t \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0e\n\x06schema\x18\x0b \x01(\t\x12\x0c\n\x04type\x18\x0c \x01(\t\x12\x1d\n\x15user_specified_system\x18\r \x01(\t\x12\x1b\n\x13user_specified_type\x18\x0e \x01(\t\x12O\n\x10gcs_fileset_spec\x18\x0f \x01(\x0b\x32\x35.oak9.tython.gcp.data.DataCatalogEntryXGcsFilesetSpec\x12\x41\n\x08timeouts\x18\x10 \x01(\x0b\x32/.oak9.tython.gcp.data.DataCatalogEntryXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a>\n\x1c\x42igqueryDateShardedSpecEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16\x42igqueryTableSpecEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\n\x1e\x44\x61taCatalogEntryGroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x96\x02\n\x15\x44\x61taCatalogEntryGroup\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x16\n\x0e\x65ntry_group_id\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0e\n\x06region\x18\x07 \x01(\t\x12\x46\n\x08timeouts\x18\x08 \x01(\x0b\x32\x34.oak9.tython.gcp.data.DataCatalogEntryGroupXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"c\n)DataCatalogEntryGroupIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9d\x02\n\x1f\x44\x61taCatalogEntryGroupIamBinding\x12\x13\n\x0b\x65ntry_group\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12R\n\tcondition\x18\x08 \x01(\x0b\x32?.oak9.tython.gcp.data.DataCatalogEntryGroupIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"b\n(DataCatalogEntryGroupIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9a\x02\n\x1e\x44\x61taCatalogEntryGroupIamMember\x12\x13\n\x0b\x65ntry_group\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12Q\n\tcondition\x18\x08 \x01(\x0b\x32>.oak9.tython.gcp.data.DataCatalogEntryGroupIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbe\x01\n\x1e\x44\x61taCatalogEntryGroupIamPolicy\x12\x13\n\x0b\x65ntry_group\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbd\x01\n\x15\x44\x61taCatalogTagXFields\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x14\n\x0c\x64ouble_value\x18\x03 \x01(\x01\x12\x12\n\nenum_value\x18\x04 \x01(\t\x12\x12\n\nfield_name\x18\x05 \x01(\t\x12\r\n\x05order\x18\x06 \x01(\x01\x12\x14\n\x0cstring_value\x18\x07 \x01(\t\x12\x17\n\x0ftimestamp_value\x18\x08 \x01(\t\"I\n\x17\x44\x61taCatalogTagXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb1\x02\n\x0e\x44\x61taCatalogTag\x12\x0e\n\x06\x63olumn\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x12\x10\n\x08template\x18\x05 \x01(\t\x12\x1c\n\x14template_displayname\x18\x06 \x01(\t\x12;\n\x06\x66ields\x18\x07 \x03(\x0b\x32+.oak9.tython.gcp.data.DataCatalogTagXFields\x12?\n\x08timeouts\x18\x08 \x01(\x0b\x32-.oak9.tython.gcp.data.DataCatalogTagXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Q\n9DataCatalogTagTemplateXFieldsXTypeXEnumTypeXAllowedValues\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\"\x96\x01\n+DataCatalogTagTemplateXFieldsXTypeXEnumType\x12g\n\x0e\x61llowed_values\x18\x01 \x03(\x0b\x32O.oak9.tython.gcp.data.DataCatalogTagTemplateXFieldsXTypeXEnumTypeXAllowedValues\"\x92\x01\n\"DataCatalogTagTemplateXFieldsXType\x12\x16\n\x0eprimitive_type\x18\x01 \x01(\t\x12T\n\tenum_type\x18\x02 \x01(\x0b\x32\x41.oak9.tython.gcp.data.DataCatalogTagTemplateXFieldsXTypeXEnumType\"\xd6\x01\n\x1d\x44\x61taCatalogTagTemplateXFields\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x10\n\x08\x66ield_id\x18\x03 \x01(\t\x12\x13\n\x0bis_required\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\r\n\x05order\x18\x06 \x01(\x01\x12\x46\n\x04type\x18\x07 \x01(\x0b\x32\x38.oak9.tython.gcp.data.DataCatalogTagTemplateXFieldsXType\"Q\n\x1f\x44\x61taCatalogTagTemplateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xdf\x02\n\x16\x44\x61taCatalogTagTemplate\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x14\n\x0c\x66orce_delete\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x17\n\x0ftag_template_id\x18\x07 \x01(\t\x12\x43\n\x06\x66ields\x18\x08 \x03(\x0b\x32\x33.oak9.tython.gcp.data.DataCatalogTagTemplateXFields\x12G\n\x08timeouts\x18\t \x01(\x0b\x32\x35.oak9.tython.gcp.data.DataCatalogTagTemplateXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"d\n*DataCatalogTagTemplateIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xa0\x02\n DataCatalogTagTemplateIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x14\n\x0ctag_template\x18\x07 \x01(\t\x12S\n\tcondition\x18\x08 \x01(\x0b\x32@.oak9.tython.gcp.data.DataCatalogTagTemplateIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"c\n)DataCatalogTagTemplateIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9d\x02\n\x1f\x44\x61taCatalogTagTemplateIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x14\n\x0ctag_template\x18\x07 \x01(\t\x12R\n\tcondition\x18\x08 \x01(\x0b\x32?.oak9.tython.gcp.data.DataCatalogTagTemplateIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc0\x01\n\x1f\x44\x61taCatalogTagTemplateIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x14\n\x0ctag_template\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"J\n DataFusionInstanceXNetworkConfig\x12\x15\n\rip_allocation\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\"M\n\x1b\x44\x61taFusionInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xde\x06\n\x12\x44\x61taFusionInstance\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12 \n\x18\x64\x61taproc_service_account\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\"\n\x1a\x65nable_stackdriver_logging\x18\x04 \x01(\x08\x12%\n\x1d\x65nable_stackdriver_monitoring\x18\x05 \x01(\x08\x12\x12\n\ngcs_bucket\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\x44\n\x06labels\x18\x08 \x03(\x0b\x32\x34.oak9.tython.gcp.data.DataFusionInstance.LabelsEntry\x12\x0c\n\x04name\x18\t \x01(\t\x12\x46\n\x07options\x18\n \x03(\x0b\x32\x35.oak9.tython.gcp.data.DataFusionInstance.OptionsEntry\x12\x18\n\x10private_instance\x18\x0b \x01(\x08\x12\x0f\n\x07project\x18\x0c \x01(\t\x12\x0e\n\x06region\x18\r \x01(\t\x12\x18\n\x10service_endpoint\x18\x0e \x01(\t\x12\r\n\x05state\x18\x0f \x01(\t\x12\x15\n\rstate_message\x18\x10 \x01(\t\x12\x19\n\x11tenant_project_id\x18\x11 \x01(\t\x12\x0c\n\x04type\x18\x12 \x01(\t\x12\x13\n\x0bupdate_time\x18\x13 \x01(\t\x12\x0f\n\x07version\x18\x14 \x01(\t\x12N\n\x0enetwork_config\x18\x15 \x01(\x0b\x32\x36.oak9.tython.gcp.data.DataFusionInstanceXNetworkConfig\x12\x43\n\x08timeouts\x18\x16 \x01(\x0b\x32\x31.oak9.tython.gcp.data.DataFusionInstanceXTimeouts\x12\x37\n\rresource_info\x18\x17 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"w\ngDataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXInfoTypes\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xe0\x01\n\x9c\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfigXCharactersToIgnore\x12\x1a\n\x12\x63haracters_to_skip\x18\x01 \x01(\t\x12#\n\x1b\x63ommon_characters_to_ignore\x18\x02 \x01(\t\"\xaa\x03\n\x89\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfig\x12\x19\n\x11masking_character\x18\x01 \x01(\t\x12\x16\n\x0enumber_to_mask\x18\x02 \x01(\x01\x12\x15\n\rreverse_order\x18\x03 \x01(\x08\x12\xd1\x01\n\x14\x63haracters_to_ignore\x18\x04 \x03(\x0b\x32\xb2\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfigXCharactersToIgnore\"\xa8\x01\n\x97\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXContext\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xd5\x01\n\xa4\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXKmsWrapped\x12\x17\n\x0f\x63rypto_key_name\x18\x01 \x01(\t\x12\x13\n\x0bwrapped_key\x18\x02 \x01(\t\"\xb4\x01\n\xa3\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXTransient\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xb3\x01\n\xa3\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXUnwrapped\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x8f\x06\n\x99\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKey\x12\xd0\x01\n\x0bkms_wrapped\x18\x01 \x01(\x0b\x32\xba\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXKmsWrapped\x12\xcd\x01\n\ttransient\x18\x02 \x01(\x0b\x32\xb9\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXTransient\x12\xcd\x01\n\tunwrapped\x18\x03 \x01(\x0b\x32\xb9\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKeyXUnwrapped\"\xb2\x01\n\xa1\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXSurrogateInfoType\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf3\x05\n\x8f\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfig\x12\xbf\x01\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\xad\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXContext\x12\xc4\x01\n\ncrypto_key\x18\x02 \x01(\x0b\x32\xaf\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXCryptoKey\x12\xd5\x01\n\x13surrogate_info_type\x18\x03 \x01(\x0b\x32\xb7\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfigXSurrogateInfoType\"\xa8\x01\n\x97\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXContext\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xd5\x01\n\xa4\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXKmsWrapped\x12\x17\n\x0f\x63rypto_key_name\x18\x01 \x01(\t\x12\x13\n\x0bwrapped_key\x18\x02 \x01(\t\"\xb4\x01\n\xa3\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXTransient\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xb3\x01\n\xa3\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXUnwrapped\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x8f\x06\n\x99\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKey\x12\xd0\x01\n\x0bkms_wrapped\x18\x01 \x01(\x0b\x32\xba\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXKmsWrapped\x12\xcd\x01\n\ttransient\x18\x02 \x01(\x0b\x32\xb9\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXTransient\x12\xcd\x01\n\tunwrapped\x18\x03 \x01(\x0b\x32\xb9\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKeyXUnwrapped\"\xb2\x01\n\xa1\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXSurrogateInfoType\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xb4\x06\n\x8f\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfig\x12\x17\n\x0f\x63ommon_alphabet\x18\x01 \x01(\t\x12\x17\n\x0f\x63ustom_alphabet\x18\x02 \x01(\t\x12\r\n\x05radix\x18\x03 \x01(\x01\x12\xbf\x01\n\x07\x63ontext\x18\x04 \x01(\x0b\x32\xad\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXContext\x12\xc4\x01\n\ncrypto_key\x18\x05 \x01(\x0b\x32\xaf\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXCryptoKey\x12\xd5\x01\n\x13surrogate_info_type\x18\x06 \x01(\x0b\x32\xb7\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfigXSurrogateInfoType\"\xc3\x01\n\x96\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXDateValue\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\x01\x12\r\n\x05month\x18\x02 \x01(\x01\x12\x0c\n\x04year\x18\x03 \x01(\x01\"\xd9\x01\n\x96\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXTimeValue\x12\r\n\x05hours\x18\x01 \x01(\x01\x12\x0f\n\x07minutes\x18\x02 \x01(\x01\x12\r\n\x05nanos\x18\x03 \x01(\x01\x12\x0f\n\x07seconds\x18\x04 \x01(\x01\"\xa4\x05\n\x8c\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValue\x12\x15\n\rboolean_value\x18\x01 \x01(\x08\x12\x19\n\x11\x64\x61y_of_week_value\x18\x02 \x01(\t\x12\x13\n\x0b\x66loat_value\x18\x03 \x01(\x01\x12\x15\n\rinteger_value\x18\x04 \x01(\x01\x12\x14\n\x0cstring_value\x18\x05 \x01(\t\x12\x17\n\x0ftimestamp_value\x18\x06 \x01(\t\x12\xc1\x01\n\ndate_value\x18\x07 \x01(\x0b\x32\xac\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXDateValue\x12\xc1\x01\n\ntime_value\x18\x08 \x01(\x0b\x32\xac\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValueXTimeValue\"\xbf\x02\n\x83\x01\x44\x61taLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfig\x12\xb6\x01\n\tnew_value\x18\x01 \x01(\x0b\x32\xa2\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfigXNewValue\"\xb3\x07\nuDataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformation\x12%\n\x1dreplace_with_info_type_config\x18\x01 \x01(\x08\x12\xbf\x01\n\x15\x63haracter_mask_config\x18\x02 \x01(\x0b\x32\x9f\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCharacterMaskConfig\x12\xcb\x01\n\x1b\x63rypto_deterministic_config\x18\x03 \x01(\x0b\x32\xa5\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoDeterministicConfig\x12\xcd\x01\n\x1d\x63rypto_replace_ffx_fpe_config\x18\x04 \x01(\x0b\x32\xa5\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXCryptoReplaceFfxFpeConfig\x12\xb2\x01\n\x0ereplace_config\x18\x05 \x01(\x0b\x32\x99\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformationXReplaceConfig\"\xa4\x03\n]DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformations\x12\x91\x01\n\ninfo_types\x18\x01 \x03(\x0b\x32}.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXInfoTypes\x12\xae\x01\n\x18primitive_transformation\x18\x02 \x01(\x0b\x32\x8b\x01.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformationsXPrimitiveTransformation\"\xde\x01\nMDataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformations\x12\x8c\x01\n\x0ftransformations\x18\x01 \x03(\x0b\x32s.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformationsXTransformations\"\xc0\x01\n5DataLossPreventionDeidentifyTemplateXDeidentifyConfig\x12\x86\x01\n\x19info_type_transformations\x18\x01 \x01(\x0b\x32\x63.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfigXInfoTypeTransformations\"_\n-DataLossPreventionDeidentifyTemplateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf3\x02\n$DataLossPreventionDeidentifyTemplate\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12\x66\n\x11\x64\x65identify_config\x18\x06 \x01(\x0b\x32K.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXDeidentifyConfig\x12U\n\x08timeouts\x18\x07 \x01(\x0b\x32\x43.oak9.tython.gcp.data.DataLossPreventionDeidentifyTemplateXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"k\n[DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXCloudStoragePath\x12\x0c\n\x04path\x18\x01 \x01(\t\"d\nSDataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXWordList\x12\r\n\x05words\x18\x01 \x03(\t\"\xda\x02\nJDataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionary\x12\x8d\x01\n\x12\x63loud_storage_path\x18\x01 \x01(\x0b\x32q.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXCloudStoragePath\x12|\n\tword_list\x18\x02 \x01(\x0b\x32i.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionaryXWordList\"X\nHDataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXInfoType\x12\x0c\n\x04name\x18\x01 \x01(\t\"o\nEDataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXRegex\x12\x15\n\rgroup_indexes\x18\x01 \x03(\x01\x12\x0f\n\x07pattern\x18\x02 \x01(\t\"Z\nJDataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXStoredType\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xb9\x04\n?DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypes\x12\x16\n\x0e\x65xclusion_type\x18\x01 \x01(\t\x12\x12\n\nlikelihood\x18\x02 \x01(\t\x12t\n\ndictionary\x18\x03 \x01(\x0b\x32`.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXDictionary\x12q\n\tinfo_type\x18\x04 \x01(\x0b\x32^.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXInfoType\x12j\n\x05regex\x18\x05 \x01(\x0b\x32[.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXRegex\x12u\n\x0bstored_type\x18\x06 \x01(\x0b\x32`.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypesXStoredType\"I\n9DataLossPreventionInspectTemplateXInspectConfigXInfoTypes\x12\x0c\n\x04name\x18\x01 \x01(\t\"f\nVDataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoTypeXInfoType\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xe6\x01\nMDataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoType\x12\x14\n\x0cmax_findings\x18\x01 \x01(\x01\x12\x7f\n\tinfo_type\x18\x02 \x01(\x0b\x32l.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoTypeXInfoType\"\x83\x02\n6DataLossPreventionInspectTemplateXInspectConfigXLimits\x12\x1d\n\x15max_findings_per_item\x18\x01 \x01(\x01\x12 \n\x18max_findings_per_request\x18\x02 \x01(\x01\x12\x87\x01\n\x1amax_findings_per_info_type\x18\x03 \x03(\x0b\x32\x63.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXLimitsXMaxFindingsPerInfoType\"Q\nADataLossPreventionInspectTemplateXInspectConfigXRuleSetXInfoTypes\x12\x0c\n\x04name\x18\x01 \x01(\t\"w\ngDataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXCloudStoragePath\x12\x0c\n\x04path\x18\x01 \x01(\t\"p\n_DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXWordList\x12\r\n\x05words\x18\x01 \x03(\t\"\xff\x02\nVDataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionary\x12\x99\x01\n\x12\x63loud_storage_path\x18\x01 \x01(\x0b\x32}.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXCloudStoragePath\x12\x88\x01\n\tword_list\x18\x02 \x01(\x0b\x32u.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionaryXWordList\"v\nfDataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypesXInfoTypes\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf1\x01\n\\DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypes\x12\x90\x01\n\ninfo_types\x18\x01 \x03(\x0b\x32|.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypesXInfoTypes\"{\nQDataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXRegex\x12\x15\n\rgroup_indexes\x18\x01 \x03(\x01\x12\x0f\n\x07pattern\x18\x02 \x01(\t\"\xf0\x03\nKDataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRule\x12\x15\n\rmatching_type\x18\x01 \x01(\t\x12\x80\x01\n\ndictionary\x18\x02 \x01(\x0b\x32l.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXDictionary\x12\x8e\x01\n\x12\x65xclude_info_types\x18\x03 \x01(\x0b\x32r.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXExcludeInfoTypes\x12v\n\x05regex\x18\x04 \x01(\x0b\x32g.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRuleXRegex\"\x80\x01\nVDataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXHotwordRegex\x12\x15\n\rgroup_indexes\x18\x01 \x03(\x01\x12\x0f\n\x07pattern\x18\x02 \x01(\t\"\x97\x01\n^DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXLikelihoodAdjustment\x12\x18\n\x10\x66ixed_likelihood\x18\x01 \x01(\t\x12\x1b\n\x13relative_likelihood\x18\x02 \x01(\x01\"\x82\x01\nSDataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXProximity\x12\x14\n\x0cwindow_after\x18\x01 \x01(\x01\x12\x15\n\rwindow_before\x18\x02 \x01(\x01\"\xe5\x03\nIDataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRule\x12\x83\x01\n\rhotword_regex\x18\x01 \x01(\x0b\x32l.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXHotwordRegex\x12\x93\x01\n\x15likelihood_adjustment\x18\x02 \x01(\x0b\x32t.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXLikelihoodAdjustment\x12|\n\tproximity\x18\x03 \x01(\x0b\x32i.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRuleXProximity\"\xb1\x02\n=DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRules\x12y\n\x0e\x65xclusion_rule\x18\x01 \x01(\x0b\x32\x61.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXExclusionRule\x12u\n\x0chotword_rule\x18\x02 \x01(\x0b\x32_.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRulesXHotwordRule\"\x8a\x02\n7DataLossPreventionInspectTemplateXInspectConfigXRuleSet\x12k\n\ninfo_types\x18\x01 \x03(\x0b\x32W.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSetXInfoTypes\x12\x62\n\x05rules\x18\x02 \x03(\x0b\x32S.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSetXRules\"\xab\x04\n/DataLossPreventionInspectTemplateXInspectConfig\x12\x17\n\x0f\x63ontent_options\x18\x01 \x03(\t\x12\x1a\n\x12\x65xclude_info_types\x18\x02 \x01(\x08\x12\x15\n\rinclude_quote\x18\x03 \x01(\x08\x12\x16\n\x0emin_likelihood\x18\x04 \x01(\t\x12p\n\x11\x63ustom_info_types\x18\x05 \x03(\x0b\x32U.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXCustomInfoTypes\x12\x63\n\ninfo_types\x18\x06 \x03(\x0b\x32O.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXInfoTypes\x12\\\n\x06limits\x18\x07 \x01(\x0b\x32L.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXLimits\x12_\n\x08rule_set\x18\x08 \x03(\x0b\x32M.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfigXRuleSet\"\\\n*DataLossPreventionInspectTemplateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe4\x02\n!DataLossPreventionInspectTemplate\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12]\n\x0einspect_config\x18\x06 \x01(\x0b\x32\x45.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXInspectConfig\x12R\n\x08timeouts\x18\x07 \x01(\x0b\x32@.oak9.tython.gcp.data.DataLossPreventionInspectTemplateXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8b\x01\nODataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfigXTable\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08table_id\x18\x03 \x01(\t\"\xd8\x01\nIDataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfig\x12\x15\n\routput_schema\x18\x01 \x01(\t\x12t\n\x05table\x18\x02 \x01(\x0b\x32\x65.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfigXTable\"\xb6\x01\n<DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindings\x12v\n\routput_config\x18\x01 \x01(\x0b\x32_.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindingsXOutputConfig\"\x9c\x01\n/DataLossPreventionJobTriggerXInspectJobXActions\x12i\n\rsave_findings\x18\x01 \x01(\x0b\x32R.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXActionsXSaveFindings\"\x90\x01\nTDataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptionsXTableReference\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08table_id\x18\x03 \x01(\t\"\xcd\x01\nEDataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptions\x12\x83\x01\n\x0ftable_reference\x18\x01 \x01(\x0b\x32j.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptionsXTableReference\"\xa3\x01\n^DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSetXRegexFileSet\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x15\n\rexclude_regex\x18\x02 \x03(\t\x12\x15\n\rinclude_regex\x18\x03 \x03(\t\"\xef\x01\nQDataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSet\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x8c\x01\n\x0eregex_file_set\x18\x02 \x01(\x0b\x32t.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSetXRegexFileSet\"\xd2\x02\nIDataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptions\x12\x1c\n\x14\x62ytes_limit_per_file\x18\x01 \x01(\x01\x12$\n\x1c\x62ytes_limit_per_file_percent\x18\x02 \x01(\x01\x12\x12\n\nfile_types\x18\x03 \x03(\t\x12\x1b\n\x13\x66iles_limit_percent\x18\x04 \x01(\x01\x12\x15\n\rsample_method\x18\x05 \x01(\t\x12y\n\x08\x66ile_set\x18\x06 \x01(\x0b\x32g.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptionsXFileSet\"[\nKDataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXKind\x12\x0c\n\x04name\x18\x01 \x01(\t\"~\nRDataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXPartitionId\x12\x14\n\x0cnamespace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\"\xb9\x02\nFDataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptions\x12o\n\x04kind\x18\x01 \x01(\x0b\x32\x61.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXKind\x12~\n\x0cpartition_id\x18\x02 \x01(\x0b\x32h.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptionsXPartitionId\"c\nSDataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfigXTimestampField\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa4\x02\nDDataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfig\x12\x31\n)enable_auto_population_of_timespan_config\x18\x01 \x01(\x08\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\t\x12\x82\x01\n\x0ftimestamp_field\x18\x04 \x01(\x0b\x32i.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfigXTimestampField\"\x9d\x04\n5DataLossPreventionJobTriggerXInspectJobXStorageConfig\x12v\n\x11\x62ig_query_options\x18\x01 \x01(\x0b\x32[.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXStorageConfigXBigQueryOptions\x12~\n\x15\x63loud_storage_options\x18\x02 \x01(\x0b\x32_.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXStorageConfigXCloudStorageOptions\x12w\n\x11\x64\x61tastore_options\x18\x03 \x01(\x0b\x32\\.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXStorageConfigXDatastoreOptions\x12s\n\x0ftimespan_config\x18\x04 \x01(\x0b\x32Z.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXStorageConfigXTimespanConfig\"\x85\x02\n\'DataLossPreventionJobTriggerXInspectJob\x12\x1d\n\x15inspect_template_name\x18\x01 \x01(\t\x12V\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32\x45.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXActions\x12\x63\n\x0estorage_config\x18\x03 \x01(\x0b\x32K.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJobXStorageConfig\"W\n%DataLossPreventionJobTriggerXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"T\n.DataLossPreventionJobTriggerXTriggersXSchedule\x12\"\n\x1arecurrence_period_duration\x18\x01 \x01(\t\"\x7f\n%DataLossPreventionJobTriggerXTriggers\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32\x44.oak9.tython.gcp.data.DataLossPreventionJobTriggerXTriggersXSchedule\"\xc5\x03\n\x1c\x44\x61taLossPreventionJobTrigger\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x15\n\rlast_run_time\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0e\n\x06parent\x18\x06 \x01(\t\x12\x0e\n\x06status\x18\x07 \x01(\t\x12R\n\x0binspect_job\x18\x08 \x01(\x0b\x32=.oak9.tython.gcp.data.DataLossPreventionJobTriggerXInspectJob\x12M\n\x08timeouts\x18\t \x01(\x0b\x32;.oak9.tython.gcp.data.DataLossPreventionJobTriggerXTimeouts\x12M\n\x08triggers\x18\n \x03(\x0b\x32;.oak9.tython.gcp.data.DataLossPreventionJobTriggerXTriggers\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n<DataLossPreventionStoredInfoTypeXDictionaryXCloudStoragePath\x12\x0c\n\x04path\x18\x01 \x01(\t\"E\n4DataLossPreventionStoredInfoTypeXDictionaryXWordList\x12\r\n\x05words\x18\x01 \x03(\t\"\xfc\x01\n+DataLossPreventionStoredInfoTypeXDictionary\x12n\n\x12\x63loud_storage_path\x18\x01 \x01(\x0b\x32R.oak9.tython.gcp.data.DataLossPreventionStoredInfoTypeXDictionaryXCloudStoragePath\x12]\n\tword_list\x18\x02 \x01(\x0b\x32J.oak9.tython.gcp.data.DataLossPreventionStoredInfoTypeXDictionaryXWordList\"Z\nJDataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXField\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x86\x01\nJDataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXTable\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08table_id\x18\x03 \x01(\t\"\xa8\x02\nDDataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryField\x12o\n\x05\x66ield\x18\x01 \x01(\x0b\x32`.oak9.tython.gcp.data.DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXField\x12o\n\x05table\x18\x02 \x01(\x0b\x32`.oak9.tython.gcp.data.DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryFieldXTable\"Y\nJDataLossPreventionStoredInfoTypeXLargeCustomDictionaryXCloudStorageFileSet\x12\x0b\n\x03url\x18\x01 \x01(\t\"Q\nADataLossPreventionStoredInfoTypeXLargeCustomDictionaryXOutputPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x9e\x03\n6DataLossPreventionStoredInfoTypeXLargeCustomDictionary\x12s\n\x0f\x62ig_query_field\x18\x01 \x01(\x0b\x32Z.oak9.tython.gcp.data.DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXBigQueryField\x12\x80\x01\n\x16\x63loud_storage_file_set\x18\x02 \x01(\x0b\x32`.oak9.tython.gcp.data.DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXCloudStorageFileSet\x12l\n\x0boutput_path\x18\x03 \x01(\x0b\x32W.oak9.tython.gcp.data.DataLossPreventionStoredInfoTypeXLargeCustomDictionaryXOutputPath\"P\n&DataLossPreventionStoredInfoTypeXRegex\x12\x15\n\rgroup_indexes\x18\x01 \x03(\x01\x12\x0f\n\x07pattern\x18\x02 \x01(\t\"[\n)DataLossPreventionStoredInfoTypeXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x96\x04\n DataLossPreventionStoredInfoType\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12U\n\ndictionary\x18\x06 \x01(\x0b\x32\x41.oak9.tython.gcp.data.DataLossPreventionStoredInfoTypeXDictionary\x12m\n\x17large_custom_dictionary\x18\x07 \x01(\x0b\x32L.oak9.tython.gcp.data.DataLossPreventionStoredInfoTypeXLargeCustomDictionary\x12K\n\x05regex\x18\x08 \x01(\x0b\x32<.oak9.tython.gcp.data.DataLossPreventionStoredInfoTypeXRegex\x12Q\n\x08timeouts\x18\t \x01(\x0b\x32?.oak9.tython.gcp.data.DataLossPreventionStoredInfoTypeXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_data_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATACATALOGENTRYXGCSFILESETSPEC_SAMPLEGCSFILESPECSENTRY._options = None
  _DATACATALOGENTRYXGCSFILESETSPEC_SAMPLEGCSFILESPECSENTRY._serialized_options = b'8\001'
  _DATACATALOGENTRY_BIGQUERYDATESHARDEDSPECENTRY._options = None
  _DATACATALOGENTRY_BIGQUERYDATESHARDEDSPECENTRY._serialized_options = b'8\001'
  _DATACATALOGENTRY_BIGQUERYTABLESPECENTRY._options = None
  _DATACATALOGENTRY_BIGQUERYTABLESPECENTRY._serialized_options = b'8\001'
  _DATAFUSIONINSTANCE_LABELSENTRY._options = None
  _DATAFUSIONINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _DATAFUSIONINSTANCE_OPTIONSENTRY._options = None
  _DATAFUSIONINSTANCE_OPTIONSENTRY._serialized_options = b'8\001'
  _DATACATALOGENTRYXGCSFILESETSPEC._serialized_start=66
  _DATACATALOGENTRYXGCSFILESETSPEC._serialized_end=291
  _DATACATALOGENTRYXGCSFILESETSPEC_SAMPLEGCSFILESPECSENTRY._serialized_start=234
  _DATACATALOGENTRYXGCSFILESETSPEC_SAMPLEGCSFILESPECSENTRY._serialized_end=291
  _DATACATALOGENTRYXTIMEOUTS._serialized_start=293
  _DATACATALOGENTRYXTIMEOUTS._serialized_end=368
  _DATACATALOGENTRY._serialized_start=371
  _DATACATALOGENTRY._serialized_end=1163
  _DATACATALOGENTRY_BIGQUERYDATESHARDEDSPECENTRY._serialized_start=1043
  _DATACATALOGENTRY_BIGQUERYDATESHARDEDSPECENTRY._serialized_end=1105
  _DATACATALOGENTRY_BIGQUERYTABLESPECENTRY._serialized_start=1107
  _DATACATALOGENTRY_BIGQUERYTABLESPECENTRY._serialized_end=1163
  _DATACATALOGENTRYGROUPXTIMEOUTS._serialized_start=1165
  _DATACATALOGENTRYGROUPXTIMEOUTS._serialized_end=1245
  _DATACATALOGENTRYGROUP._serialized_start=1248
  _DATACATALOGENTRYGROUP._serialized_end=1526
  _DATACATALOGENTRYGROUPIAMBINDINGXCONDITION._serialized_start=1528
  _DATACATALOGENTRYGROUPIAMBINDINGXCONDITION._serialized_end=1627
  _DATACATALOGENTRYGROUPIAMBINDING._serialized_start=1630
  _DATACATALOGENTRYGROUPIAMBINDING._serialized_end=1915
  _DATACATALOGENTRYGROUPIAMMEMBERXCONDITION._serialized_start=1917
  _DATACATALOGENTRYGROUPIAMMEMBERXCONDITION._serialized_end=2015
  _DATACATALOGENTRYGROUPIAMMEMBER._serialized_start=2018
  _DATACATALOGENTRYGROUPIAMMEMBER._serialized_end=2300
  _DATACATALOGENTRYGROUPIAMPOLICY._serialized_start=2303
  _DATACATALOGENTRYGROUPIAMPOLICY._serialized_end=2493
  _DATACATALOGTAGXFIELDS._serialized_start=2496
  _DATACATALOGTAGXFIELDS._serialized_end=2685
  _DATACATALOGTAGXTIMEOUTS._serialized_start=2687
  _DATACATALOGTAGXTIMEOUTS._serialized_end=2760
  _DATACATALOGTAG._serialized_start=2763
  _DATACATALOGTAG._serialized_end=3068
  _DATACATALOGTAGTEMPLATEXFIELDSXTYPEXENUMTYPEXALLOWEDVALUES._serialized_start=3070
  _DATACATALOGTAGTEMPLATEXFIELDSXTYPEXENUMTYPEXALLOWEDVALUES._serialized_end=3151
  _DATACATALOGTAGTEMPLATEXFIELDSXTYPEXENUMTYPE._serialized_start=3154
  _DATACATALOGTAGTEMPLATEXFIELDSXTYPEXENUMTYPE._serialized_end=3304
  _DATACATALOGTAGTEMPLATEXFIELDSXTYPE._serialized_start=3307
  _DATACATALOGTAGTEMPLATEXFIELDSXTYPE._serialized_end=3453
  _DATACATALOGTAGTEMPLATEXFIELDS._serialized_start=3456
  _DATACATALOGTAGTEMPLATEXFIELDS._serialized_end=3670
  _DATACATALOGTAGTEMPLATEXTIMEOUTS._serialized_start=3672
  _DATACATALOGTAGTEMPLATEXTIMEOUTS._serialized_end=3753
  _DATACATALOGTAGTEMPLATE._serialized_start=3756
  _DATACATALOGTAGTEMPLATE._serialized_end=4107
  _DATACATALOGTAGTEMPLATEIAMBINDINGXCONDITION._serialized_start=4109
  _DATACATALOGTAGTEMPLATEIAMBINDINGXCONDITION._serialized_end=4209
  _DATACATALOGTAGTEMPLATEIAMBINDING._serialized_start=4212
  _DATACATALOGTAGTEMPLATEIAMBINDING._serialized_end=4500
  _DATACATALOGTAGTEMPLATEIAMMEMBERXCONDITION._serialized_start=4502
  _DATACATALOGTAGTEMPLATEIAMMEMBERXCONDITION._serialized_end=4601
  _DATACATALOGTAGTEMPLATEIAMMEMBER._serialized_start=4604
  _DATACATALOGTAGTEMPLATEIAMMEMBER._serialized_end=4889
  _DATACATALOGTAGTEMPLATEIAMPOLICY._serialized_start=4892
  _DATACATALOGTAGTEMPLATEIAMPOLICY._serialized_end=5084
  _DATAFUSIONINSTANCEXNETWORKCONFIG._serialized_start=5086
  _DATAFUSIONINSTANCEXNETWORKCONFIG._serialized_end=5160
  _DATAFUSIONINSTANCEXTIMEOUTS._serialized_start=5162
  _DATAFUSIONINSTANCEXTIMEOUTS._serialized_end=5239
  _DATAFUSIONINSTANCE._serialized_start=5242
  _DATAFUSIONINSTANCE._serialized_end=6104
  _DATAFUSIONINSTANCE_LABELSENTRY._serialized_start=6011
  _DATAFUSIONINSTANCE_LABELSENTRY._serialized_end=6056
  _DATAFUSIONINSTANCE_OPTIONSENTRY._serialized_start=6058
  _DATAFUSIONINSTANCE_OPTIONSENTRY._serialized_end=6104
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXINFOTYPES._serialized_start=6106
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXINFOTYPES._serialized_end=6225
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCHARACTERMASKCONFIGXCHARACTERSTOIGNORE._serialized_start=6228
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCHARACTERMASKCONFIGXCHARACTERSTOIGNORE._serialized_end=6452
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCHARACTERMASKCONFIG._serialized_start=6455
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCHARACTERMASKCONFIG._serialized_end=6881
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIGXCONTEXT._serialized_start=6884
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIGXCONTEXT._serialized_end=7052
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIGXCRYPTOKEYXKMSWRAPPED._serialized_start=7055
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIGXCRYPTOKEYXKMSWRAPPED._serialized_end=7268
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIGXCRYPTOKEYXTRANSIENT._serialized_start=7271
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIGXCRYPTOKEYXTRANSIENT._serialized_end=7451
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIGXCRYPTOKEYXUNWRAPPED._serialized_start=7454
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIGXCRYPTOKEYXUNWRAPPED._serialized_end=7633
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIGXCRYPTOKEY._serialized_start=7636
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIGXCRYPTOKEY._serialized_end=8419
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIGXSURROGATEINFOTYPE._serialized_start=8422
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIGXSURROGATEINFOTYPE._serialized_end=8600
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIG._serialized_start=8603
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTODETERMINISTICCONFIG._serialized_end=9358
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIGXCONTEXT._serialized_start=9361
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIGXCONTEXT._serialized_end=9529
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIGXCRYPTOKEYXKMSWRAPPED._serialized_start=9532
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIGXCRYPTOKEYXKMSWRAPPED._serialized_end=9745
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIGXCRYPTOKEYXTRANSIENT._serialized_start=9748
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIGXCRYPTOKEYXTRANSIENT._serialized_end=9928
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIGXCRYPTOKEYXUNWRAPPED._serialized_start=9931
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIGXCRYPTOKEYXUNWRAPPED._serialized_end=10110
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIGXCRYPTOKEY._serialized_start=10113
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIGXCRYPTOKEY._serialized_end=10896
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIGXSURROGATEINFOTYPE._serialized_start=10899
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIGXSURROGATEINFOTYPE._serialized_end=11077
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIG._serialized_start=11080
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXCRYPTOREPLACEFFXFPECONFIG._serialized_end=11900
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXREPLACECONFIGXNEWVALUEXDATEVALUE._serialized_start=11903
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXREPLACECONFIGXNEWVALUEXDATEVALUE._serialized_end=12098
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXREPLACECONFIGXNEWVALUEXTIMEVALUE._serialized_start=12101
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXREPLACECONFIGXNEWVALUEXTIMEVALUE._serialized_end=12318
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXREPLACECONFIGXNEWVALUE._serialized_start=12321
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXREPLACECONFIGXNEWVALUE._serialized_end=12997
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXREPLACECONFIG._serialized_start=13000
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATIONXREPLACECONFIG._serialized_end=13319
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATION._serialized_start=13322
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONSXPRIMITIVETRANSFORMATION._serialized_end=14269
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONS._serialized_start=14272
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONSXTRANSFORMATIONS._serialized_end=14692
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONS._serialized_start=14695
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIGXINFOTYPETRANSFORMATIONS._serialized_end=14917
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIG._serialized_start=14920
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXDEIDENTIFYCONFIG._serialized_end=15112
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXTIMEOUTS._serialized_start=15114
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATEXTIMEOUTS._serialized_end=15209
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATE._serialized_start=15212
  _DATALOSSPREVENTIONDEIDENTIFYTEMPLATE._serialized_end=15583
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPESXDICTIONARYXCLOUDSTORAGEPATH._serialized_start=15585
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPESXDICTIONARYXCLOUDSTORAGEPATH._serialized_end=15692
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPESXDICTIONARYXWORDLIST._serialized_start=15694
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPESXDICTIONARYXWORDLIST._serialized_end=15794
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPESXDICTIONARY._serialized_start=15797
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPESXDICTIONARY._serialized_end=16143
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPESXINFOTYPE._serialized_start=16145
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPESXINFOTYPE._serialized_end=16233
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPESXREGEX._serialized_start=16235
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPESXREGEX._serialized_end=16346
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPESXSTOREDTYPE._serialized_start=16348
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPESXSTOREDTYPE._serialized_end=16438
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPES._serialized_start=16441
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXCUSTOMINFOTYPES._serialized_end=17010
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXINFOTYPES._serialized_start=17012
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXINFOTYPES._serialized_end=17085
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXLIMITSXMAXFINDINGSPERINFOTYPEXINFOTYPE._serialized_start=17087
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXLIMITSXMAXFINDINGSPERINFOTYPEXINFOTYPE._serialized_end=17189
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXLIMITSXMAXFINDINGSPERINFOTYPE._serialized_start=17192
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXLIMITSXMAXFINDINGSPERINFOTYPE._serialized_end=17422
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXLIMITS._serialized_start=17425
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXLIMITS._serialized_end=17684
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXINFOTYPES._serialized_start=17686
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXINFOTYPES._serialized_end=17767
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULEXDICTIONARYXCLOUDSTORAGEPATH._serialized_start=17769
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULEXDICTIONARYXCLOUDSTORAGEPATH._serialized_end=17888
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULEXDICTIONARYXWORDLIST._serialized_start=17890
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULEXDICTIONARYXWORDLIST._serialized_end=18002
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULEXDICTIONARY._serialized_start=18005
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULEXDICTIONARY._serialized_end=18388
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULEXEXCLUDEINFOTYPESXINFOTYPES._serialized_start=18390
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULEXEXCLUDEINFOTYPESXINFOTYPES._serialized_end=18508
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULEXEXCLUDEINFOTYPES._serialized_start=18511
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULEXEXCLUDEINFOTYPES._serialized_end=18752
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULEXREGEX._serialized_start=18754
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULEXREGEX._serialized_end=18877
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULE._serialized_start=18880
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXEXCLUSIONRULE._serialized_end=19376
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXHOTWORDRULEXHOTWORDREGEX._serialized_start=19379
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXHOTWORDRULEXHOTWORDREGEX._serialized_end=19507
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXHOTWORDRULEXLIKELIHOODADJUSTMENT._serialized_start=19510
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXHOTWORDRULEXLIKELIHOODADJUSTMENT._serialized_end=19661
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXHOTWORDRULEXPROXIMITY._serialized_start=19664
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXHOTWORDRULEXPROXIMITY._serialized_end=19794
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXHOTWORDRULE._serialized_start=19797
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULESXHOTWORDRULE._serialized_end=20282
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULES._serialized_start=20285
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESETXRULES._serialized_end=20590
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESET._serialized_start=20593
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIGXRULESET._serialized_end=20859
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIG._serialized_start=20862
  _DATALOSSPREVENTIONINSPECTTEMPLATEXINSPECTCONFIG._serialized_end=21417
  _DATALOSSPREVENTIONINSPECTTEMPLATEXTIMEOUTS._serialized_start=21419
  _DATALOSSPREVENTIONINSPECTTEMPLATEXTIMEOUTS._serialized_end=21511
  _DATALOSSPREVENTIONINSPECTTEMPLATE._serialized_start=21514
  _DATALOSSPREVENTIONINSPECTTEMPLATE._serialized_end=21870
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXACTIONSXSAVEFINDINGSXOUTPUTCONFIGXTABLE._serialized_start=21873
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXACTIONSXSAVEFINDINGSXOUTPUTCONFIGXTABLE._serialized_end=22012
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXACTIONSXSAVEFINDINGSXOUTPUTCONFIG._serialized_start=22015
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXACTIONSXSAVEFINDINGSXOUTPUTCONFIG._serialized_end=22231
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXACTIONSXSAVEFINDINGS._serialized_start=22234
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXACTIONSXSAVEFINDINGS._serialized_end=22416
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXACTIONS._serialized_start=22419
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXACTIONS._serialized_end=22575
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXBIGQUERYOPTIONSXTABLEREFERENCE._serialized_start=22578
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXBIGQUERYOPTIONSXTABLEREFERENCE._serialized_end=22722
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXBIGQUERYOPTIONS._serialized_start=22725
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXBIGQUERYOPTIONS._serialized_end=22930
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXCLOUDSTORAGEOPTIONSXFILESETXREGEXFILESET._serialized_start=22933
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXCLOUDSTORAGEOPTIONSXFILESETXREGEXFILESET._serialized_end=23096
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXCLOUDSTORAGEOPTIONSXFILESET._serialized_start=23099
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXCLOUDSTORAGEOPTIONSXFILESET._serialized_end=23338
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXCLOUDSTORAGEOPTIONS._serialized_start=23341
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXCLOUDSTORAGEOPTIONS._serialized_end=23679
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXDATASTOREOPTIONSXKIND._serialized_start=23681
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXDATASTOREOPTIONSXKIND._serialized_end=23772
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXDATASTOREOPTIONSXPARTITIONID._serialized_start=23774
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXDATASTOREOPTIONSXPARTITIONID._serialized_end=23900
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXDATASTOREOPTIONS._serialized_start=23903
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXDATASTOREOPTIONS._serialized_end=24216
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXTIMESPANCONFIGXTIMESTAMPFIELD._serialized_start=24218
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXTIMESPANCONFIGXTIMESTAMPFIELD._serialized_end=24317
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXTIMESPANCONFIG._serialized_start=24320
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIGXTIMESPANCONFIG._serialized_end=24612
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIG._serialized_start=24615
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOBXSTORAGECONFIG._serialized_end=25156
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOB._serialized_start=25159
  _DATALOSSPREVENTIONJOBTRIGGERXINSPECTJOB._serialized_end=25420
  _DATALOSSPREVENTIONJOBTRIGGERXTIMEOUTS._serialized_start=25422
  _DATALOSSPREVENTIONJOBTRIGGERXTIMEOUTS._serialized_end=25509
  _DATALOSSPREVENTIONJOBTRIGGERXTRIGGERSXSCHEDULE._serialized_start=25511
  _DATALOSSPREVENTIONJOBTRIGGERXTRIGGERSXSCHEDULE._serialized_end=25595
  _DATALOSSPREVENTIONJOBTRIGGERXTRIGGERS._serialized_start=25597
  _DATALOSSPREVENTIONJOBTRIGGERXTRIGGERS._serialized_end=25724
  _DATALOSSPREVENTIONJOBTRIGGER._serialized_start=25727
  _DATALOSSPREVENTIONJOBTRIGGER._serialized_end=26180
  _DATALOSSPREVENTIONSTOREDINFOTYPEXDICTIONARYXCLOUDSTORAGEPATH._serialized_start=26182
  _DATALOSSPREVENTIONSTOREDINFOTYPEXDICTIONARYXCLOUDSTORAGEPATH._serialized_end=26258
  _DATALOSSPREVENTIONSTOREDINFOTYPEXDICTIONARYXWORDLIST._serialized_start=26260
  _DATALOSSPREVENTIONSTOREDINFOTYPEXDICTIONARYXWORDLIST._serialized_end=26329
  _DATALOSSPREVENTIONSTOREDINFOTYPEXDICTIONARY._serialized_start=26332
  _DATALOSSPREVENTIONSTOREDINFOTYPEXDICTIONARY._serialized_end=26584
  _DATALOSSPREVENTIONSTOREDINFOTYPEXLARGECUSTOMDICTIONARYXBIGQUERYFIELDXFIELD._serialized_start=26586
  _DATALOSSPREVENTIONSTOREDINFOTYPEXLARGECUSTOMDICTIONARYXBIGQUERYFIELDXFIELD._serialized_end=26676
  _DATALOSSPREVENTIONSTOREDINFOTYPEXLARGECUSTOMDICTIONARYXBIGQUERYFIELDXTABLE._serialized_start=26679
  _DATALOSSPREVENTIONSTOREDINFOTYPEXLARGECUSTOMDICTIONARYXBIGQUERYFIELDXTABLE._serialized_end=26813
  _DATALOSSPREVENTIONSTOREDINFOTYPEXLARGECUSTOMDICTIONARYXBIGQUERYFIELD._serialized_start=26816
  _DATALOSSPREVENTIONSTOREDINFOTYPEXLARGECUSTOMDICTIONARYXBIGQUERYFIELD._serialized_end=27112
  _DATALOSSPREVENTIONSTOREDINFOTYPEXLARGECUSTOMDICTIONARYXCLOUDSTORAGEFILESET._serialized_start=27114
  _DATALOSSPREVENTIONSTOREDINFOTYPEXLARGECUSTOMDICTIONARYXCLOUDSTORAGEFILESET._serialized_end=27203
  _DATALOSSPREVENTIONSTOREDINFOTYPEXLARGECUSTOMDICTIONARYXOUTPUTPATH._serialized_start=27205
  _DATALOSSPREVENTIONSTOREDINFOTYPEXLARGECUSTOMDICTIONARYXOUTPUTPATH._serialized_end=27286
  _DATALOSSPREVENTIONSTOREDINFOTYPEXLARGECUSTOMDICTIONARY._serialized_start=27289
  _DATALOSSPREVENTIONSTOREDINFOTYPEXLARGECUSTOMDICTIONARY._serialized_end=27703
  _DATALOSSPREVENTIONSTOREDINFOTYPEXREGEX._serialized_start=27705
  _DATALOSSPREVENTIONSTOREDINFOTYPEXREGEX._serialized_end=27785
  _DATALOSSPREVENTIONSTOREDINFOTYPEXTIMEOUTS._serialized_start=27787
  _DATALOSSPREVENTIONSTOREDINFOTYPEXTIMEOUTS._serialized_end=27878
  _DATALOSSPREVENTIONSTOREDINFOTYPE._serialized_start=27881
  _DATALOSSPREVENTIONSTOREDINFOTYPE._serialized_end=28415
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApigeeEndpointAttachmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ApigeeEndpointAttachmentXTimeouts = ApigeeEndpointAttachmentXTimeouts

@typing_extensions.final
class ApigeeEndpointAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINT_ATTACHMENT_ID_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    SERVICE_ATTACHMENT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    endpoint_attachment_id: builtins.str
    host: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    org_id: builtins.str
    service_attachment: builtins.str
    @property
    def timeouts(self) -> global___ApigeeEndpointAttachmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        endpoint_attachment_id: builtins.str = ...,
        host: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        org_id: builtins.str = ...,
        service_attachment: builtins.str = ...,
        timeouts: global___ApigeeEndpointAttachmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_attachment_id", b"endpoint_attachment_id", "host", b"host", "id", b"id", "location", b"location", "name", b"name", "org_id", b"org_id", "resource_info", b"resource_info", "service_attachment", b"service_attachment", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeEndpointAttachment = ApigeeEndpointAttachment

@typing_extensions.final
class ApigeeEnvgroupXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ApigeeEnvgroupXTimeouts = ApigeeEnvgroupXTimeouts

@typing_extensions.final
class ApigeeEnvgroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTNAMES_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def hostnames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    id: builtins.str
    name: builtins.str
    org_id: builtins.str
    @property
    def timeouts(self) -> global___ApigeeEnvgroupXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        hostnames: collections.abc.Iterable[builtins.str] | None = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        org_id: builtins.str = ...,
        timeouts: global___ApigeeEnvgroupXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hostnames", b"hostnames", "id", b"id", "name", b"name", "org_id", b"org_id", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeEnvgroup = ApigeeEnvgroup

@typing_extensions.final
class ApigeeEnvgroupAttachmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ApigeeEnvgroupAttachmentXTimeouts = ApigeeEnvgroupAttachmentXTimeouts

@typing_extensions.final
class ApigeeEnvgroupAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVGROUP_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    envgroup_id: builtins.str
    environment: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def timeouts(self) -> global___ApigeeEnvgroupAttachmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        envgroup_id: builtins.str = ...,
        environment: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        timeouts: global___ApigeeEnvgroupAttachmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["envgroup_id", b"envgroup_id", "environment", b"environment", "id", b"id", "name", b"name", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeEnvgroupAttachment = ApigeeEnvgroupAttachment

@typing_extensions.final
class ApigeeEnvironmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ApigeeEnvironmentXTimeouts = ApigeeEnvironmentXTimeouts

@typing_extensions.final
class ApigeeEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_PROXY_TYPE_FIELD_NUMBER: builtins.int
    DEPLOYMENT_TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_proxy_type: builtins.str
    deployment_type: builtins.str
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    org_id: builtins.str
    @property
    def timeouts(self) -> global___ApigeeEnvironmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_proxy_type: builtins.str = ...,
        deployment_type: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        org_id: builtins.str = ...,
        timeouts: global___ApigeeEnvironmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_proxy_type", b"api_proxy_type", "deployment_type", b"deployment_type", "description", b"description", "display_name", b"display_name", "id", b"id", "name", b"name", "org_id", b"org_id", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeEnvironment = ApigeeEnvironment

@typing_extensions.final
class ApigeeEnvironmentIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ApigeeEnvironmentIamBindingXCondition = ApigeeEnvironmentIamBindingXCondition

@typing_extensions.final
class ApigeeEnvironmentIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENV_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    env_id: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    org_id: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ApigeeEnvironmentIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        env_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        org_id: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ApigeeEnvironmentIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "env_id", b"env_id", "etag", b"etag", "id", b"id", "members", b"members", "org_id", b"org_id", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ApigeeEnvironmentIamBinding = ApigeeEnvironmentIamBinding

@typing_extensions.final
class ApigeeEnvironmentIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ApigeeEnvironmentIamMemberXCondition = ApigeeEnvironmentIamMemberXCondition

@typing_extensions.final
class ApigeeEnvironmentIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENV_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    env_id: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    org_id: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ApigeeEnvironmentIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        env_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        org_id: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ApigeeEnvironmentIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "env_id", b"env_id", "etag", b"etag", "id", b"id", "member", b"member", "org_id", b"org_id", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ApigeeEnvironmentIamMember = ApigeeEnvironmentIamMember

@typing_extensions.final
class ApigeeEnvironmentIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENV_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    env_id: builtins.str
    etag: builtins.str
    id: builtins.str
    org_id: builtins.str
    policy_data: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        env_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        org_id: builtins.str = ...,
        policy_data: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["env_id", b"env_id", "etag", b"etag", "id", b"id", "org_id", b"org_id", "policy_data", b"policy_data", "resource_info", b"resource_info"]) -> None: ...

global___ApigeeEnvironmentIamPolicy = ApigeeEnvironmentIamPolicy

@typing_extensions.final
class ApigeeInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ApigeeInstanceXTimeouts = ApigeeInstanceXTimeouts

@typing_extensions.final
class ApigeeInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSUMER_ACCEPT_LIST_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_KEY_NAME_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_RANGE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    PEERING_CIDR_RANGE_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    SERVICE_ATTACHMENT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def consumer_accept_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    description: builtins.str
    disk_encryption_key_name: builtins.str
    display_name: builtins.str
    host: builtins.str
    id: builtins.str
    ip_range: builtins.str
    location: builtins.str
    name: builtins.str
    org_id: builtins.str
    peering_cidr_range: builtins.str
    port: builtins.str
    service_attachment: builtins.str
    @property
    def timeouts(self) -> global___ApigeeInstanceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        consumer_accept_list: collections.abc.Iterable[builtins.str] | None = ...,
        description: builtins.str = ...,
        disk_encryption_key_name: builtins.str = ...,
        display_name: builtins.str = ...,
        host: builtins.str = ...,
        id: builtins.str = ...,
        ip_range: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        org_id: builtins.str = ...,
        peering_cidr_range: builtins.str = ...,
        port: builtins.str = ...,
        service_attachment: builtins.str = ...,
        timeouts: global___ApigeeInstanceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["consumer_accept_list", b"consumer_accept_list", "description", b"description", "disk_encryption_key_name", b"disk_encryption_key_name", "display_name", b"display_name", "host", b"host", "id", b"id", "ip_range", b"ip_range", "location", b"location", "name", b"name", "org_id", b"org_id", "peering_cidr_range", b"peering_cidr_range", "port", b"port", "resource_info", b"resource_info", "service_attachment", b"service_attachment", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeInstance = ApigeeInstance

@typing_extensions.final
class ApigeeInstanceAttachmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ApigeeInstanceAttachmentXTimeouts = ApigeeInstanceAttachmentXTimeouts

@typing_extensions.final
class ApigeeInstanceAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    environment: builtins.str
    id: builtins.str
    instance_id: builtins.str
    name: builtins.str
    @property
    def timeouts(self) -> global___ApigeeInstanceAttachmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        environment: builtins.str = ...,
        id: builtins.str = ...,
        instance_id: builtins.str = ...,
        name: builtins.str = ...,
        timeouts: global___ApigeeInstanceAttachmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment", "id", b"id", "instance_id", b"instance_id", "name", b"name", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeInstanceAttachment = ApigeeInstanceAttachment

@typing_extensions.final
class ApigeeOrganizationXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ApigeeOrganizationXTimeouts = ApigeeOrganizationXTimeouts

@typing_extensions.final
class ApigeeOrganization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANALYTICS_REGION_FIELD_NUMBER: builtins.int
    AUTHORIZED_NETWORK_FIELD_NUMBER: builtins.int
    BILLING_TYPE_FIELD_NUMBER: builtins.int
    CA_CERTIFICATE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    RUNTIME_DATABASE_ENCRYPTION_KEY_NAME_FIELD_NUMBER: builtins.int
    RUNTIME_TYPE_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_TYPE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    analytics_region: builtins.str
    authorized_network: builtins.str
    billing_type: builtins.str
    ca_certificate: builtins.str
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    project_id: builtins.str
    runtime_database_encryption_key_name: builtins.str
    runtime_type: builtins.str
    subscription_type: builtins.str
    @property
    def timeouts(self) -> global___ApigeeOrganizationXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        analytics_region: builtins.str = ...,
        authorized_network: builtins.str = ...,
        billing_type: builtins.str = ...,
        ca_certificate: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project_id: builtins.str = ...,
        runtime_database_encryption_key_name: builtins.str = ...,
        runtime_type: builtins.str = ...,
        subscription_type: builtins.str = ...,
        timeouts: global___ApigeeOrganizationXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["analytics_region", b"analytics_region", "authorized_network", b"authorized_network", "billing_type", b"billing_type", "ca_certificate", b"ca_certificate", "description", b"description", "display_name", b"display_name", "id", b"id", "name", b"name", "project_id", b"project_id", "resource_info", b"resource_info", "runtime_database_encryption_key_name", b"runtime_database_encryption_key_name", "runtime_type", b"runtime_type", "subscription_type", b"subscription_type", "timeouts", b"timeouts"]) -> None: ...

global___ApigeeOrganization = ApigeeOrganization



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_gke.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_gke.proto\x12\x13oak9.tython.gcp.gke\x1a\x13shared/shared.proto\",\n\x1aGkeHubMembershipXAuthority\x12\x0e\n\x06issuer\x18\x01 \x01(\t\"=\n$GkeHubMembershipXEndpointXGkeCluster\x12\x15\n\rresource_link\x18\x01 \x01(\t\"k\n\x19GkeHubMembershipXEndpoint\x12N\n\x0bgke_cluster\x18\x01 \x01(\x0b\x32\x39.oak9.tython.gcp.gke.GkeHubMembershipXEndpointXGkeCluster\"K\n\x19GkeHubMembershipXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc7\x03\n\x10GkeHubMembership\x12\n\n\x02id\x18\x01 \x01(\t\x12\x41\n\x06labels\x18\x02 \x03(\x0b\x32\x31.oak9.tython.gcp.gke.GkeHubMembership.LabelsEntry\x12\x15\n\rmembership_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x42\n\tauthority\x18\x06 \x01(\x0b\x32/.oak9.tython.gcp.gke.GkeHubMembershipXAuthority\x12@\n\x08\x65ndpoint\x18\x07 \x01(\x0b\x32..oak9.tython.gcp.gke.GkeHubMembershipXEndpoint\x12@\n\x08timeouts\x18\x08 \x01(\x0b\x32..oak9.tython.gcp.gke.GkeHubMembershipXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_gke_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GKEHUBMEMBERSHIP_LABELSENTRY._options = None
  _GKEHUBMEMBERSHIP_LABELSENTRY._serialized_options = b'8\001'
  _GKEHUBMEMBERSHIPXAUTHORITY._serialized_start=63
  _GKEHUBMEMBERSHIPXAUTHORITY._serialized_end=107
  _GKEHUBMEMBERSHIPXENDPOINTXGKECLUSTER._serialized_start=109
  _GKEHUBMEMBERSHIPXENDPOINTXGKECLUSTER._serialized_end=170
  _GKEHUBMEMBERSHIPXENDPOINT._serialized_start=172
  _GKEHUBMEMBERSHIPXENDPOINT._serialized_end=279
  _GKEHUBMEMBERSHIPXTIMEOUTS._serialized_start=281
  _GKEHUBMEMBERSHIPXTIMEOUTS._serialized_end=356
  _GKEHUBMEMBERSHIP._serialized_start=359
  _GKEHUBMEMBERSHIP._serialized_end=814
  _GKEHUBMEMBERSHIP_LABELSENTRY._serialized_start=769
  _GKEHUBMEMBERSHIP_LABELSENTRY._serialized_end=814
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_mediaconvert.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61ws/aws_mediaconvert.proto\x12\x1coak9.tython.aws.mediaconvert\x1a\x13shared/shared.proto\"h\n\x1fJobTemplateAccelerationSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04mode\x18\x02 \x01(\t\"\x8b\x01\n\x19JobTemplateHopDestination\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cwait_minutes\x18\x02 \x01(\x05\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12\r\n\x05queue\x18\x04 \x01(\t\"\xe6\x04\n\x0bJobTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\\\n\x15\x61\x63\x63\x65leration_settings\x18\x04 \x01(\x0b\x32=.oak9.tython.aws.mediaconvert.JobTemplateAccelerationSettings\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12\x1e\n\x16status_update_interval\x18\x06 \x01(\t\x12R\n\rsettings_json\x18\x07 \x03(\x0b\x32;.oak9.tython.aws.mediaconvert.JobTemplate.SettingsJsonEntry\x12\r\n\x05queue\x18\x08 \x01(\t\x12Q\n\x10hop_destinations\x18\t \x03(\x0b\x32\x37.oak9.tython.aws.mediaconvert.JobTemplateHopDestination\x12\x41\n\x04tags\x18\n \x03(\x0b\x32\x33.oak9.tython.aws.mediaconvert.JobTemplate.TagsEntry\x12\x0c\n\x04name\x18\x0b \x01(\t\x1a\x33\n\x11SettingsJsonEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb9\x01\n\x0cMediaConvert\x12?\n\x0cjob_template\x18\x01 \x03(\x0b\x32).oak9.tython.aws.mediaconvert.JobTemplate\x12\x34\n\x06preset\x18\x02 \x03(\x0b\x32$.oak9.tython.aws.mediaconvert.Preset\x12\x32\n\x05queue\x18\x03 \x03(\x0b\x32#.oak9.tython.aws.mediaconvert.Queue\"\xe5\x02\n\x06Preset\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12M\n\rsettings_json\x18\x04 \x03(\x0b\x32\x36.oak9.tython.aws.mediaconvert.Preset.SettingsJsonEntry\x12<\n\x04tags\x18\x05 \x03(\x0b\x32..oak9.tython.aws.mediaconvert.Preset.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a\x33\n\x11SettingsJsonEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf3\x01\n\x05Queue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0cpricing_plan\x18\x04 \x01(\t\x12;\n\x04tags\x18\x05 \x03(\x0b\x32-.oak9.tython.aws.mediaconvert.Queue.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_mediaconvert_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JOBTEMPLATE_SETTINGSJSONENTRY._options = None
  _JOBTEMPLATE_SETTINGSJSONENTRY._serialized_options = b'8\001'
  _JOBTEMPLATE_TAGSENTRY._options = None
  _JOBTEMPLATE_TAGSENTRY._serialized_options = b'8\001'
  _PRESET_SETTINGSJSONENTRY._options = None
  _PRESET_SETTINGSJSONENTRY._serialized_options = b'8\001'
  _PRESET_TAGSENTRY._options = None
  _PRESET_TAGSENTRY._serialized_options = b'8\001'
  _QUEUE_TAGSENTRY._options = None
  _QUEUE_TAGSENTRY._serialized_options = b'8\001'
  _JOBTEMPLATEACCELERATIONSETTINGS._serialized_start=81
  _JOBTEMPLATEACCELERATIONSETTINGS._serialized_end=185
  _JOBTEMPLATEHOPDESTINATION._serialized_start=188
  _JOBTEMPLATEHOPDESTINATION._serialized_end=327
  _JOBTEMPLATE._serialized_start=330
  _JOBTEMPLATE._serialized_end=944
  _JOBTEMPLATE_SETTINGSJSONENTRY._serialized_start=848
  _JOBTEMPLATE_SETTINGSJSONENTRY._serialized_end=899
  _JOBTEMPLATE_TAGSENTRY._serialized_start=901
  _JOBTEMPLATE_TAGSENTRY._serialized_end=944
  _MEDIACONVERT._serialized_start=947
  _MEDIACONVERT._serialized_end=1132
  _PRESET._serialized_start=1135
  _PRESET._serialized_end=1492
  _PRESET_SETTINGSJSONENTRY._serialized_start=848
  _PRESET_SETTINGSJSONENTRY._serialized_end=899
  _PRESET_TAGSENTRY._serialized_start=901
  _PRESET_TAGSENTRY._serialized_end=944
  _QUEUE._serialized_start=1495
  _QUEUE._serialized_end=1738
  _QUEUE_TAGSENTRY._serialized_start=901
  _QUEUE_TAGSENTRY._serialized_end=944
# @@protoc_insertion_point(module_scope)
